==> qt-creator-opensource-src-4.0.3.zip: qt-creator-opensource-src-4.0.3/src/plugins/debugger/imageviewer.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#ifndef IMAGEVIEWER_H
#define IMAGEVIEWER_H

#include <QWidget>

#include <vector>

QT_BEGIN_NAMESPACE
class QScrollArea;
class QLabel;
class QImage;
class QContextMenuEvent;
QT_END_NAMESPACE

class ImageWidget;

// Image viewer showing images in scroll area, displays color on click.
class ImageViewer : public QWidget
{
    Q_OBJECT
public:
    explicit ImageViewer(QWidget *parent = 0);

    void setImage(const QImage &image);
    void setInfo(const QString &description);

protected:
    void contextMenuEvent(QContextMenuEvent *);

private:
    void clicked(const QString &);

    QScrollArea *m_scrollArea;
    ImageWidget *m_imageWidget;
    QLabel *m_infoLabel;
    QString m_info;
};

class PlotViewer : public QWidget
{
    Q_OBJECT
public:
    explicit PlotViewer(QWidget *parent = 0);

    typedef std::vector<double> Data;
    void setData(const Data &data);
    void setInfo(const QString &description);

    void paintEvent(QPaintEvent *ev);

private:
    Data m_data;
    QString m_info;
};

#endif // IMAGEVIEWER_H

==> qt-creator-opensource-src-4.7.1.zip: qt-creator-opensource-src-4.7.1/src/plugins/debugger/imageviewer.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <QWidget>

#include <vector>

QT_BEGIN_NAMESPACE
class QScrollArea;
class QLabel;
class QImage;
class QContextMenuEvent;
QT_END_NAMESPACE

class ImageWidget;

// Image viewer showing images in scroll area, displays color on click.
class ImageViewer : public QWidget
{
    Q_OBJECT
public:
    explicit ImageViewer(QWidget *parent = nullptr);

    void setImage(const QImage &image);
    void setInfo(const QString &description);

private:
    void contextMenuEvent(QContextMenuEvent *) final;
    void clicked(const QString &);

    QScrollArea *m_scrollArea;
    ImageWidget *m_imageWidget;
    QLabel *m_infoLabel;
    QString m_info;
};

class PlotViewer : public QWidget
{
    Q_OBJECT
public:
    explicit PlotViewer(QWidget *parent = nullptr);

    typedef std::vector<double> Data;
    void setData(const Data &data);
    void setInfo(const QString &description);

    void paintEvent(QPaintEvent *ev) final;

private:
    Data m_data;
    QString m_info;
};
